<?php
/**
 * Defines customizer options
 *
 * This file is loaded at 'after_setup_theme' hook with 10 priority.
 *
 * @package    Metrolo
 */

/**
 * Build the Customizer options (panels, sections, settings)
 *
 * Always remember to mention specific priority for non-static options like:
 *     - options being added based on a condition (eg: if woocommerce is active)
 *     - options which may get removed (eg: logo_size, headings_fontface)
 *     - options which may get rearranged (eg: logo_background_type)
 *     This will allow other options inserted with priority to be inserted at
 *     their intended place.
 *
 * @since 1.0
 * @access public
 * @return array
 */
if ( !function_exists( 'hoot_theme_customizer_options' ) ) :
function hoot_theme_customizer_options() {

	// Stores all the settings to be added
	$settings = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Theme default colors and fonts
	extract( apply_filters( 'hoot_theme_options_defaults', array(
		'accent_color'             => '#d02121',
		'accent_font'              => '#ffffff',
		'contrast_color'           => '#1c1c1c',
		'contrast_font'            => '#ffffff',
		'box_background'           => '#ffffff',
		'site_background'          => '#ffffff',
		'wt_html_slide_background' => '#ffffff',
	) ) );

	// Directory path for radioimage buttons
	$imagepath =  HYBRIDEXTEND_INCURI . 'admin/images/';

	// Logo Sizes (different range than standard typography range)
	$logosizes = array();
	$logosizerange = range( 14, 110 );
	foreach ( $logosizerange as $isr )
		$logosizes[ $isr . 'px' ] = $isr . 'px';
	$logosizes = apply_filters( 'hoot_theme_options_logosizes', $logosizes);

	// Logo Font Options for Lite version
	$logofont = apply_filters( 'hoot_theme_options_logofont', array(
					'standard' => __('Standard Body Font', 'metrolo'),
					'heading' => __('Logo Font (Styling > Typography)', 'metrolo'),
					) );

	/*** Add Options (Panels, Sections, Settings) ***/

	/** Panel Setup & Layout **/

	$panel = 'general';

	$panels[ $panel ] = array(
		'title'    => __( 'Setup & Layout', 'metrolo' ),
	);

	$section = 'setup';

	$sections[ $section ] = array(
		'title'       => __( 'Site Setup', 'metrolo' ),
		'panel'       => $panel,
		// 'description' => __( '', 'metrolo' ),
	);

	$settings['site_layout'] = array(
		'label'       => __( 'Site Layout - Boxed vs Stretched', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'choices'     => array(
			'boxed'   => __('Boxed layout', 'metrolo'),
			'stretch' => __('Stretched layout (full width)', 'metrolo'),
		),
		'default'     => 'stretch',
		'description' => __("For boxed layouts, both backgrounds (site and content box) can be set in the 'Styling > Backgrounds' panel.<br /><br />For Stretched Layout, only site background is available.", 'metrolo'),
	);

	$settings['site_width'] = array(
		'label'       => __( 'Max. Site Width (pixels)', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'choices'     => array(
			'1260' => __('1260px (wide)', 'metrolo'),
			'1080' => __('1080px (standard)', 'metrolo'),
		),
		'default'     => '1260',
	);

	$settings['load_minified'] = array(
		'label'       => __( 'Load Minified Styles and Scripts (when available)', 'metrolo' ),
		'sublabel'    => __( 'Checking this option reduces data size, hence increasing page load speed.', 'metrolo' ),
		'section'     => $section,
		'type'        => 'checkbox',
		'priority'    => '25', // Non static options must have a priority
	);

	$section = 'logo';

	$sections[ $section ] = array(
		'title'       => __( 'Logo Settings', 'metrolo' ),
		'panel'       => $panel,
		// 'description' => __( '', 'metrolo' ),
	);

	$settings['logo_background_type'] = array(
		'label'       => __( 'Logo Background', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'priority'    => '25', // Non static options must have a priority
		'choices'     => array(
			'transparent' => __('None', 'metrolo'),
			'accent'      => __('Accent Color', 'metrolo'),
		),
		'default'     => 'accent',
	);

	$settings['logo'] = array(
		'label'       => __( 'Site Logo', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'choices'     => array(
			'text'        => __('Default Text (Site Title)', 'metrolo'),
			'custom'      => __('Custom Text', 'metrolo'),
			'image'       => __('Image Logo', 'metrolo'),
			'mixed'       => __('Image &amp; Default Text (Site Title)', 'metrolo'),
			'mixedcustom' => __('Image &amp; Custom Text', 'metrolo'),
		),
		'default'     => 'text',
		'description' => sprintf( __('Use %sSite Title%s as default text logo', 'metrolo'), '<a href="' . esc_url( admin_url('options-general.php') ) . '" target="_blank">', '</a>' ),
	);

	$settings['logo_size'] = array(
		'label'       => __( 'Logo Size', 'metrolo' ),
		'section'     => $section,
		'type'        => 'select',
		'priority'    => '35', // Non static options must have a priority
		'choices'     => array(
			'tiny'               => __( 'Tiny', 'metrolo'),
			'tiny displayfont'   => __( 'Tiny Bold', 'metrolo'),
			'small'              => __( 'Small', 'metrolo'),
			'small displayfont'  => __( 'Small Bold', 'metrolo'),
			'medium'             => __( 'Medium', 'metrolo'),
			'medium displayfont' => __( 'Medium Bold', 'metrolo'),
			'large'              => __( 'Large', 'metrolo'),
			'large displayfont'  => __( 'Large Bold', 'metrolo'),
			'huge'               => __( 'Huge', 'metrolo'),
			'huge displayfont'   => __( 'Huge Bold', 'metrolo'),
		),
		'default'     => 'small displayfont',
		'active_callback' => 'hoot_callback_logo_size',
	);

	$settings['site_title_icon'] = array(
		'label'           => __( 'Site Title Icon (Optional)', 'metrolo' ),
		'section'         => $section,
		'type'            => 'icon',
		// 'default'         => 'fa-anchor',
		'description'     => __( 'Leave empty to hide icon.', 'metrolo' ),
		'active_callback' => 'hoot_callback_site_title_icon',
	);

	$settings['site_title_icon_size'] = array(
		'label'           => __( 'Site Title Icon Size', 'metrolo' ),
		'section'         => $section,
		'type'            => 'select',
		'choices'         => $logosizes,
		'default'         => '50px',
		'active_callback' => 'hoot_callback_site_title_icon',
	);

	if ( ! function_exists( 'the_custom_logo' ) )
	$settings['logo_image'] = array(
		'label'           => __( 'Upload Logo', 'metrolo' ),
		'section'         => $section,
		'type'            => 'image',
		'priority'        => '55', // Replaced by WP's custom_logo if available // Update in premium if needed
		'active_callback' => 'hoot_callback_logo_image',
	);

	$settings['logo_image_width'] = array(
		'label'           => __( 'Maximum Logo Width', 'metrolo' ),
		'section'         => $section,
		'type'            => 'text',
		'priority'        => '56', // Keep it with image logo // Update in premium if needed
		'default'         => 200,
		'description'     => __( '(in pixels)<hr>The logo width may be automatically adjusted by the browser depending on title length and space available.', 'metrolo' ),
		'input_attrs'     => array(
			'min'         => 0,
			'max'         => 3,
			'placeholder' => __( '(in pixels)', 'metrolo' ),
		),
		'active_callback' => 'hoot_callback_logo_image_width',
	);

	$logo_custom_line_options = array(
		'text' => array(
			'label'       => __( 'Line Text', 'metrolo' ),
			'type'        => 'text',
		),
		'size' => array(
			'label'       => __( 'Line Size', 'metrolo' ),
			'type'        => 'select',
			'choices'     => $logosizes,
			'default'     => '20px',
		),
		'font' => array(
			'label'       => __( 'Line Font', 'metrolo' ),
			'type'        => 'select',
			'choices'     => $logofont,
			'default'     => 'heading',
		),
	);

	$settings['logo_custom'] = array(
		'label'           => __( 'Custom Logo Text', 'metrolo' ),
		'section'         => $section,
		'type'            => 'sortlist',
		'choices'         => array(
			'line1' => __('Line 1', 'metrolo'),
			'line2' => __('Line 2', 'metrolo'),
			'line3' => __('Line 3', 'metrolo'),
			'line4' => __('Line 4', 'metrolo'),
		),
		'options'         => array(
			'line1' => $logo_custom_line_options,
			'line2' => $logo_custom_line_options,
			'line3' => $logo_custom_line_options,
			'line4' => $logo_custom_line_options,
		),
		'attributes'      => array(
			'inactive' => array( 'line3', 'line4' ),
			'hideable' => true,
			'sortable' => false,
		),
		'active_callback' => 'hoot_callback_logo_custom',
	);

	$settings['show_tagline'] = array(
		'label'           => __( 'Show Tagline', 'metrolo' ),
		'sublabel'        => __( 'Display site description as tagline below logo.', 'metrolo' ),
		'section'         => $section,
		'type'            => 'checkbox',
		'default'         => 1,
		'active_callback' => 'hoot_callback_show_tagline',
	);

	$section = 'header_layout';

	$sections[ $section ] = array(
		'title'       => __( 'Header Layout', 'metrolo' ),
		'panel'       => $panel,
		// 'description' => __( '', 'metrolo' ),
	);

	$settings['header_layout_help'] = array(
		'section'     => $section,
		'type'        => 'content',
		'content'     => '<em>' . __( 'Select options below to create a variety of header layouts. Example:', 'metrolo' ) . '</em><br><img src="' . $imagepath . 'header-layout.png">',
	);

	$settings['primary_menuarea'] = array(
		'label'       => __( 'Primary Area (right of logo)', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'choices'     => array(
			'menu'        => __('Display Primary Menu', 'metrolo'),
			'custom'      => __('Custom Text', 'metrolo'),
			'none'        => __('None (Logo will get centre aligned)', 'metrolo'),
		),
		'default'     => 'menu',
	);

	$settings['primary_menuarea_custom'] = array(
		'label'             => __( 'Custom Text instead of Menu', 'metrolo' ),
		'section'           => $section,
		'type'              => 'textarea',
		'description'       => __( 'You can use this area to display ads or custom text.', 'metrolo' ),
		'active_callback'   => 'hoot_callback_show_primary_menuarea_custom',
	);
	// Allow users to add javascript in case they need to use this area to insert code for ads
	// etc. To enable this, add the following code in your child theme's functions.php file (without
	// the '//'). This code is already included in premium version.
	//     add_filter( 'primary_menuarea_custom_allowscript', 'hoot_child_textarea_allowscript' );
	//     function hoot_child_textarea_allowscript(){ return true; }
	if ( apply_filters( 'primary_menuarea_custom_allowscript', true ) )
		$settings['primary_menuarea_custom']['sanitize_callback'] = 'hoot_custom_sanitize_textarea_allowscript';

	$settings['secondary_menu_location'] = array(
		'label'       => __( 'Secondary Menu Location', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'choices'     => array(
			'top'        => __('Top (above logo)', 'metrolo'),
			'bottom'     => __('Bottom (below logo)', 'metrolo'),
			'none'       => __('Do not display secondary menu', 'metrolo'),
		),
		'default'     => 'bottom',
	);

	$settings['secondary_menu_align'] = array(
		'label'       => __( 'Secondary Menu Alignment', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'choices'     => array(
			'left'      => __('Left', 'metrolo'),
			'right'     => __('Right', 'metrolo'),
			'center'    => __('Center', 'metrolo'),
		),
		'default'     => 'center',
	);

	$settings['disable_flex_menu'] = array(
		'label'       => __( 'Disable Flex Menu', 'metrolo' ),
		'section'     => $section,
		'type'        => 'checkbox',
		'default'     => 1,
		'description' => __( 'Disable Flex Menu if you have a lot of Top Level menu items.', 'metrolo' ),
	);

	$section = 'sidebar_layout';

	$sections[ $section ] = array(
		'title'       => __( 'Sidebar Layout', 'metrolo' ),
		'panel'       => $panel,
		'description' => sprintf( __( 'If you are using %1sJetpack%2s, use the %3s"Widget Visibility"%4s module to display different sidebar content on different pages of your site.', 'metrolo' ), '<a href="https://wordpress.org/plugins/jetpack/" target="_blank">', '</a>', '<a href="https://jetpack.com/support/widget-visibility/" target="_blank">', '</a>' ),
	);

	$settings['sidebar'] = array(
		'label'       => __( 'Sidebar Layout (Site-wide)', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radioimage',
		'choices'     => array(
			'wide-right'         => $imagepath . 'sidebar-wide-right.png',
			'narrow-right'       => $imagepath . 'sidebar-narrow-right.png',
			'wide-left'          => $imagepath . 'sidebar-wide-left.png',
			'narrow-left'        => $imagepath . 'sidebar-narrow-left.png',
			'narrow-left-right'  => $imagepath . 'sidebar-narrow-left-right.png',
			'narrow-left-left'   => $imagepath . 'sidebar-narrow-left-left.png',
			'narrow-right-right' => $imagepath . 'sidebar-narrow-right-right.png',
			'full-width'         => $imagepath . 'sidebar-full.png',
			'none'               => $imagepath . 'sidebar-none.png',
		),
		'default'     => 'wide-right',
		'description' => __("Set the default sidebar width and position for your site.", 'metrolo'),
	);

	$settings['sidebar_pages'] = array(
		'label'       => __( 'Sidebar Layout (for Pages)', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radioimage',
		'choices'     => array(
			'wide-right'         => $imagepath . 'sidebar-wide-right.png',
			'narrow-right'       => $imagepath . 'sidebar-narrow-right.png',
			'wide-left'          => $imagepath . 'sidebar-wide-left.png',
			'narrow-left'        => $imagepath . 'sidebar-narrow-left.png',
			'narrow-left-right'  => $imagepath . 'sidebar-narrow-left-right.png',
			'narrow-left-left'   => $imagepath . 'sidebar-narrow-left-left.png',
			'narrow-right-right' => $imagepath . 'sidebar-narrow-right-right.png',
			'full-width'         => $imagepath . 'sidebar-full.png',
			'none'               => $imagepath . 'sidebar-none.png',
		),
		'default'     => 'wide-right',
	);

	$settings['sidebar_posts'] = array(
		'label'       => __( 'Sidebar Layout (for single Posts)', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radioimage',
		'choices'     => array(
			'wide-right'         => $imagepath . 'sidebar-wide-right.png',
			'narrow-right'       => $imagepath . 'sidebar-narrow-right.png',
			'wide-left'          => $imagepath . 'sidebar-wide-left.png',
			'narrow-left'        => $imagepath . 'sidebar-narrow-left.png',
			'narrow-left-right'  => $imagepath . 'sidebar-narrow-left-right.png',
			'narrow-left-left'   => $imagepath . 'sidebar-narrow-left-left.png',
			'narrow-right-right' => $imagepath . 'sidebar-narrow-right-right.png',
			'full-width'         => $imagepath . 'sidebar-full.png',
			'none'               => $imagepath . 'sidebar-none.png',
		),
		'default'     => 'wide-right',
	);

	if ( current_theme_supports( 'woocommerce' ) ) :

		$settings['sidebar_wooshop'] = array(
			'label'       => __( 'Sidebar Layout (Woocommerce Shop/Archives)', 'metrolo' ),
			'section'     => $section,
			'type'        => 'radioimage',
			'priority'    => '155', // Non static options must have a priority
			'choices'     => array(
				'wide-right'         => $imagepath . 'sidebar-wide-right.png',
				'narrow-right'       => $imagepath . 'sidebar-narrow-right.png',
				'wide-left'          => $imagepath . 'sidebar-wide-left.png',
				'narrow-left'        => $imagepath . 'sidebar-narrow-left.png',
				'narrow-left-right'  => $imagepath . 'sidebar-narrow-left-right.png',
				'narrow-left-left'   => $imagepath . 'sidebar-narrow-left-left.png',
				'narrow-right-right' => $imagepath . 'sidebar-narrow-right-right.png',
				'full-width'         => $imagepath . 'sidebar-full.png',
				'none'               => $imagepath . 'sidebar-none.png',
			),
			'default'     => 'wide-right',
			'description' => __("Set the default sidebar width and position for WooCommerce Shop and Archives pages like product categories etc.", 'metrolo'),
		);

		$settings['sidebar_wooproduct'] = array(
			'label'       => __( 'Sidebar Layout (Woocommerce Single Product Page)', 'metrolo' ),
			'section'     => $section,
			'type'        => 'radioimage',
			'priority'    => '155', // Non static options must have a priority
			'choices'     => array(
				'wide-right'         => $imagepath . 'sidebar-wide-right.png',
				'narrow-right'       => $imagepath . 'sidebar-narrow-right.png',
				'wide-left'          => $imagepath . 'sidebar-wide-left.png',
				'narrow-left'        => $imagepath . 'sidebar-narrow-left.png',
				'narrow-left-right'  => $imagepath . 'sidebar-narrow-left-right.png',
				'narrow-left-left'   => $imagepath . 'sidebar-narrow-left-left.png',
				'narrow-right-right' => $imagepath . 'sidebar-narrow-right-right.png',
				'full-width'         => $imagepath . 'sidebar-full.png',
				'none'               => $imagepath . 'sidebar-none.png',
			),
			'default'     => 'wide-right',
			'description' => __("Set the default sidebar width and position for WooCommerce product page", 'metrolo'),
		);

	endif;

	$section = 'archives';

	$sections[ $section ] = array(
		'title'       => __( 'Archives (Blog, Cats, Tags)', 'metrolo' ),
		'panel'       => $panel,
		// 'description' => __( '', 'metrolo' ),
	);

	$settings['archive_post_content'] = array(
		'label'       => __( 'Post Items Content', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'choices'     => array(
			'excerpt' => __('Post Excerpt', 'metrolo'),
			'full-content' => __('Full Post Content', 'metrolo'),
		),
		'default'     => 'excerpt',
		'description' => __( 'Content to display for each post in the list', 'metrolo' ),
	);

	$settings['archive_post_meta'] = array(
		'label'       => __( 'Meta Information for Post List Items', 'metrolo' ),
		'sublabel'    => __( 'Check which meta information to display for each post item in the archive list.', 'metrolo' ),
		'section'     => $section,
		'type'        => 'checkbox',
		'choices'     => array(
			'author'   => __('Author', 'metrolo'),
			'date'     => __('Date', 'metrolo'),
			'cats'     => __('Categories', 'metrolo'),
			'tags'     => __('Tags', 'metrolo'),
			'comments' => __('No. of comments', 'metrolo')
		),
		'default'     => 'author, date, cats, comments',
	);

	$settings['excerpt_length'] = array(
		'label'       => __( 'Excerpt Length', 'metrolo' ),
		'section'     => $section,
		'type'        => 'text',
		'description' => __( 'Number of words in excerpt. Default is 105. Leave empty if you dont want to change it.', 'metrolo' ),
		'input_attrs' => array(
			'min' => 0,
			'max' => 3,
			'placeholder' => __( 'default: 105', 'metrolo' ),
		),
	);

	$settings['read_more'] = array(
		'label'       => __( "'Read More' Text", 'metrolo' ),
		'section'     => $section,
		'type'        => 'text',
		'description' => __( "Replace the default 'Read More' text. Leave empty if you dont want to change it.", 'metrolo' ),
		'input_attrs' => array(
			'placeholder' => __( 'default: READ MORE &rarr;', 'metrolo' ),
		),
	);

	$section = 'singular';

	$sections[ $section ] = array(
		'title'       => __( 'Single (Posts, Pages)', 'metrolo' ),
		'panel'       => $panel,
		// 'description' => __( '', 'metrolo' ),
	);

	$settings['page_header_full'] = array(
		'label'       => __( 'Stretch Page Header to Full Width', 'metrolo' ),
		'sublabel'    => '<img src="' . $imagepath . 'page-header.png">',
		'section'     => $section,
		'type'        => 'checkbox',
		'choices'     => array(
			'default'    => __('Default (Archives, Blog etc.)', 'metrolo'),
			'posts'      => __('For All Posts', 'metrolo'),
			'pages'      => __('For All Pages', 'metrolo'),
			'no-sidebar' => __('Always override for full width pages (any page which has no sidebar)', 'metrolo'),
		),
		'default'     => 'default, pages',
		'description' => __('This is the Page Header area containing Page/Post Title and Meta details like author, categories etc.', 'metrolo'),
	);

	$settings['post_featured_image'] = array(
		'label'       => __( 'Display Featured Image', 'metrolo' ),
		'sublabel'    => __( 'Display featured image at the beginning of post/page content.', 'metrolo' ),
		'section'     => $section,
		'type'        => 'checkbox',
		'default'     => 1,
	);

	$settings['post_meta'] = array(
		'label'       => __( 'Meta Information on Posts', 'metrolo' ),
		'sublabel'    => __( "Check which meta information to display on an individual 'Post' page", 'metrolo' ),
		'section'     => $section,
		'type'        => 'checkbox',
		'choices'     => array(
			'author'   => __('Author', 'metrolo'),
			'date'     => __('Date', 'metrolo'),
			'cats'     => __('Categories', 'metrolo'),
			'tags'     => __('Tags', 'metrolo'),
			'comments' => __('No. of comments', 'metrolo')
		),
		'default'     => 'author, date, cats, tags, comments',
	);

	$settings['page_meta'] = array(
		'label'       => __( 'Meta Information on Page', 'metrolo' ),
		'sublabel'    => __( "Check which meta information to display on an individual 'Page' page", 'metrolo' ),
		'section'     => $section,
		'type'        => 'checkbox',
		'choices'     => array(
			'author'   => __('Author', 'metrolo'),
			'date'     => __('Date', 'metrolo'),
			'comments' => __('No. of comments', 'metrolo')
		),
		'default'     => 'author, date, comments',
	);

	$settings['post_meta_location'] = array(
		'label'       => __( 'Meta Information location', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radio',
		'choices'     => array(
			'top'    => __('Top (below title)', 'metrolo'),
			'bottom' => __('Bottom (after content)', 'metrolo'),
		),
		'default'     => 'top',
	);

	$settings['post_prev_next_links'] = array(
		'label'       => __( 'Previous/Next Posts', 'metrolo' ),
		'sublabel'    => __( 'Display links to Prev/Next Post links at the end of post content.', 'metrolo' ),
		'section'     => $section,
		'type'        => 'checkbox',
		'default'     => 1,
	);

	if ( current_theme_supports( 'woocommerce' ) ) :

		$section = 'woocommerce';

		$sections[ $section ] = array(
			'title'       => __( 'WooCommerce', 'metrolo' ),
			'panel'       => $panel,
			// 'description' => __( '', 'metrolo' ),
			'priority'    => '65', // Non static options must have a priority
		);

		$wooproducts = range( 0, 99 );
		for ( $wpr=0; $wpr < 4; $wpr++ )
			unset( $wooproducts[$wpr] );
		$settings['wooshop_products'] = array(
			'label'       => __( 'Total Products per page', 'metrolo' ),
			'section'     => $section,
			'type'        => 'select',
			'priority'    => '255', // Non static options must have a priority
			'choices'     => $wooproducts,
			'default'     => '12',
			'description' => __( 'Total number of products to show on the Shop page', 'metrolo' ),
		);

		$settings['wooshop_product_columns'] = array(
			'label'       => __( 'Product Columns', 'metrolo' ),
			'section'     => $section,
			'type'        => 'select',
			'priority'    => '255', // Non static options must have a priority
			'choices'     => array(
				'2' => '2',
				'3' => '3',
				'4' => '4',
				'5' => '5',
			),
			'default'     => '3',
			'description' => __( 'Number of products to show in 1 row on the Shop page', 'metrolo' ),
		);

	endif;

	$section = 'footer';

	$sections[ $section ] = array(
		'title'       => __( 'Footer', 'metrolo' ),
		'panel'       => $panel,
		// 'description' => __( '', 'metrolo' ),
	);

	$settings['footer'] = array(
		'label'       => __( 'Footer Layout', 'metrolo' ),
		'section'     => $section,
		'type'        => 'radioimage',
		'choices'     => array(
			'1-1' => $imagepath . '1-1.png',
			'2-1' => $imagepath . '2-1.png',
			'2-2' => $imagepath . '2-2.png',
			'2-3' => $imagepath . '2-3.png',
			'3-1' => $imagepath . '3-1.png',
			'3-2' => $imagepath . '3-2.png',
			'3-3' => $imagepath . '3-3.png',
			'3-4' => $imagepath . '3-4.png',
			'4-1' => $imagepath . '4-1.png',
		),
		'default'     => '3-1',
		'description' => sprintf( __('You must first save the changes you make here and refresh this screen for footer columns to appear in the Widgets panel (in customizer).<hr> Once you save the settings here, you can add content to footer columns using the %sWidgets Management screen%s.', 'metrolo'), '<a href="' . esc_url( admin_url('widgets.php') ) . '" target="_blank">', '</a>' ),
	);

	$settings['site_info'] = array(
		'label'       => __( 'Site Info Text (footer)', 'metrolo' ),
		'section'     => $section,
		'type'        => 'textarea',
		'default'     => __( '<!--default-->', 'metrolo'),
		'description' => sprintf( __('Text shown in footer. Useful for showing copyright info etc.<hr>Use the <code>&lt;!--default--&gt;</code> tag to show the default Info Text.<hr>Use the <code>&lt;!--year--&gt;</code> tag to insert the current year.<hr>Always use %sHTML codes%s for symbols. For example, the HTML for &copy; is <code>&amp;copy;</code>', 'metrolo'), '<a href="http://ascii.cl/htmlcodes.htm" target="_blank">', '</a>' ),
	);

	/** Panel Styling **/

	$panel = 'styling';

	$panels[ $panel ] = array(
		'title'    => __( 'Styling', 'metrolo' ),
	);

	$section = 'colors';

	// Redundant as 'colors' section is added by WP. But we still add it for brevity
	$sections[ $section ] = array(
		'title'       => __( 'Colors', 'metrolo' ),
		'panel'       => $panel,
	);

	$settings['box_background_color'] = array(
		'label'       => __( 'Content Box Background', 'metrolo' ),
		'section'     => $section,
		'type'        => 'color',
		'default'     => $box_background,
		'description' => __("This background is available only when <strong>'Boxed'</strong> option is selected in the <strong>'Setup &amp; Layout > Site Setup'</strong> panel.", 'metrolo'),
	);

	$settings['accent_color'] = array(
		'label'       => __( 'Accent Color', 'metrolo' ),
		'section'     => $section,
		'type'        => 'color',
		'default'     => $accent_color,
	);

	$settings['accent_font'] = array(
		'label'       => __( 'Font Color on Accent Color', 'metrolo' ),
		'section'     => $section,
		'type'        => 'color',
		'default'     => $accent_font,
	);

	$settings['contrast_color'] = array(
		'label'       => __( 'Contrast Color', 'metrolo' ),
		'section'     => $section,
		'type'        => 'color',
		'default'     => $contrast_color,
	);

	$settings['contrast_font'] = array(
		'label'       => __( 'Font Color on Contrast Color', 'metrolo' ),
		'section'     => $section,
		'type'        => 'color',
		'default'     => $contrast_font,
	);

	$section = 'typography';

	$sections[ $section ] = array(
		'title'       => __( 'Typography', 'metrolo' ),
		'panel'       => $panel,
		'priority'    => '85', // Non static options must have a priority
	);

	$settings['logo_fontface'] = array(
		'label'       => __( 'Logo Font (Free Version)', 'metrolo' ),
		'section'     => $section,
		'type'        => 'select',
		'priority'    => 305, // Non static options must have a priority
		'choices'     => array(
			'logo'     => __( 'Default Logo Font (Trebuchet MS)', 'metrolo' ),
			'standard' => __( 'Body Font (Open Sans)', 'metrolo'),
			'cursive'  => __( 'Cursive Font (Pacifico)', 'metrolo'),
		),
		'default'     => 'logo',
	);

	$settings['heading_transform'] = array(
		'label'       => __( 'General Headings Style', 'metrolo' ),
		'section'     => $section,
		'type'        => 'select',
		'priority'    => 425, // Non static options must have a priority
		'choices'     => array(
			'none'      => __( 'Normal', 'metrolo'),
			'uppercase' => __( 'Uppercase', 'metrolo'),
		),
		'default'     => 'uppercase',
	);

	/** Panel Content **/

	$panel = 'content';

	$panels[ $panel ] = array(
		'title'    => __( 'Content', 'metrolo' ),
	);

	$section = 'topbar';

	$sections[ $section ] = array(
		'title'       => __( 'Topbar', 'metrolo' ),
		'panel'       => $panel,
		// 'description' => __( '', 'metrolo' ),
	);

	$settings['topbar-widget-areas'] = array(
		'label'       => __( 'Left/Right Topbar', 'metrolo' ),
		'section'     => $section,
		'type'        => 'content',
		'content'     => sprintf( __('You can add content to Left/Right Topbar using Text Widget in the %sWidget Management Screen%s', 'metrolo'), '<a href="' . esc_url( admin_url('widgets.php') ) . '" target="_blank">', '</a>' ),
	);

	$settings['topbar_hide_search'] = array(
		'label'       => __( 'Hide Search Box', 'metrolo' ),
		'sublabel'    => __( 'Check this to hide Search box in Topbar Right Column', 'metrolo' ),
		'section'     => $section,
		'type'        => 'checkbox',
	);

	if ( current_theme_supports( 'hoot-widgetized-template' ) ) :

		$section = 'widgetized-template';

		$sections[ $section ] = array(
			'title'       => __( 'Widgetized Template - Modules', 'metrolo' ),
			'panel'       => $panel,
			'description' => sprintf( __( "<strong>How to use this template</strong><p>'Widgetized Template' is a special Page Template which is often used as a quick way to create a Front Page.</p><ol><li>Create a %sNew Page%s. In the <strong>'Page Attributes'</strong> option box select the <strong>'Widgetized Template'</strong> in the <strong>'Template'</strong> dropdown.</li><li>Goto %sSetting > Reading%s menu. In the <strong>'Front page displays'</strong> option, select <strong>'A static page'</strong> and select the page you created in previous step.</li></ol>", 'metrolo'),'<a href="' . esc_url( admin_url('post-new.php?post_type=page') ) . '" target="_blank">', '</a>','<a href="' . esc_url( admin_url('options-reading.php') ) . '" target="_blank">', '</a>'),
		);

		$widget_area_options = array(
			'columns' => array(
				'label'   => __( 'Columns', 'metrolo' ),
				'type'    => 'select',
				'choices' => array(
					'100'         => __('One Column [100]', 'metrolo'),
					'50-50'       => __('Two Columns [50 50]', 'metrolo'),
					'33-66'       => __('Two Columns [33 66]', 'metrolo'),
					'66-33'       => __('Two Columns [66 33]', 'metrolo'),
					'25-75'       => __('Two Columns [25 75]', 'metrolo'),
					'75-25'       => __('Two Columns [75 25]', 'metrolo'),
					'33-33-33'    => __('Three Columns [33 33 33]', 'metrolo'),
					'25-25-25-25' => __('Four Columns [25 25 25 25]', 'metrolo'),
				),
			),
			'modulebg' => array(
				'label'       => '',
				'type'        => 'content',
				'content'     => '<div class="button">' . __( 'Module Background', 'metrolo' ) . '</div>',
			),
		);

		$settings['widgetized_template_sections'] = array(
			'label'       => __( 'Widget Areas Order', 'metrolo' ),
			'sublabel'    => sprintf( __("<p>Sort different sections of the 'Widgetized Template' in the order you want them to appear.</p><ul><li>You can add content to widget areas from the %sWidgets Management screen%s.</li><li>You can disable areas by clicking the 'eye' icon. (This will hide them on the Widgets screen as well)</li><li>'Page Content' is the actual content of the page on which this template is applied. This can be used in special situations for creating extra customizable content.</li></ul>", 'metrolo'), '<a href="' . esc_url( admin_url('widgets.php') ) . '" target="_blank">', '</a>' ),
			'section'     => $section,
			'type'        => 'sortlist',
			'choices'     => array(
				'slider_html' => __('HTML Slider', 'metrolo'),
				'slider_img'  => __('Image Slider', 'metrolo'),
				'area_a'      => __('Widget Area A', 'metrolo'),
				'area_b'      => __('Widget Area B', 'metrolo'),
				'area_c'      => __('Widget Area C', 'metrolo'),
				'area_d'      => __('Widget Area D', 'metrolo'),
				'area_e'      => __('Widget Area E', 'metrolo'),
				'content'     => __('Page Content Area', 'metrolo'),
			),
			'default'     => array(
				'content' => array( 'sortitem_hide' => 1, ),
				'area_d'  => array( 'highlight' => 1, 'columns' => '50-50' ),
			),
			'options'     => array(
				// 'slider_html' => $widget_area_options,
				// 'slider_img'  => $widget_area_options,
				'area_a'      => $widget_area_options,
				'area_b'      => $widget_area_options,
				'area_c'      => $widget_area_options,
				'area_d'      => $widget_area_options,
				'area_e'      => $widget_area_options,
				'content'     => array( 'modulebg' => array(
									'label'       => '',
									'type'        => 'content',
									'content'     => '<div class="button">' . __( 'Module Background', 'metrolo' ) . '</div>',
								), ),
			),
			'attributes'  => array(
				'hideable'      => true,
				'sortable'      => true,
			),
			'description' => sprintf( __('You must first save the changes you make here and refresh this screen for widget areas to appear in the Widgets panel (in customizer).<hr> Once you save the settings here, you can add content to these widget areas using the %sWidgets Management screen%s.', 'metrolo'), '<a href="' . esc_url( admin_url('widgets.php') ) . '" target="_blank">', '</a>' ),
		);

		$wtmodule_bg = array(
			'area_a'      => __('Widget Area A', 'metrolo'),
			'area_b'      => __('Widget Area B', 'metrolo'),
			'area_c'      => __('Widget Area C', 'metrolo'),
			'area_d'      => __('Widget Area D', 'metrolo'),
			'area_e'      => __('Widget Area E', 'metrolo'),
			'content'     => __('Page Content Area', 'metrolo'),
			);
		foreach ( $wtmodule_bg as $wtmid => $wtmname ) {

			$settings["widgetized_template_sectionbg_{$wtmid}"] = array(
				'label'       => '', // __( 'Module Background', 'metrolo' ),
				'section'     => $section,
				'type'        => 'group',
				'button'      => __( 'Module Background', 'metrolo' ),
				'options'     => array(
					'description' => array(
						'label'       => '',
						'type'        => 'content',
						'content'     => '<span class="hoot-module-bg-title">' . $wtmname . '</span>',
					),
					'type' => array(
						'label'   => __( 'Background Type', 'metrolo' ),
						'type'    => 'select',
						'choices' => array(
							'none'        => __('None', 'metrolo'),
							'highlight'   => __('Highlight Color', 'metrolo'),
							'image'       => __('Background Image', 'metrolo'),
						),
						'default' => 'none',
					),
					'image' => array(
						'label'       => __( 'Background Image', 'metrolo' ),
						'type'        => 'image',
						'description' => __("You must select 'Image' in dropdown above for background image to work.", 'metrolo'),
					),
					'parallax' => array(
						'label'   => __( 'Apply Parallax Effect to Background Image', 'metrolo' ),
						'type'    => 'checkbox',
					),
				),
			);

		} // end for

		$section = 'slider_html';

		$sections[ $section ] = array(
			'title'       => __( 'Widgetized Template - HTML Slider', 'metrolo' ),
			'panel'       => $panel,
		);

		$settings['wt_html_slider_width'] = array(
			'label'       => __( 'Slider Width', 'metrolo' ),
			'sublabel'    => __( "Note: This option is useful only if the <strong>Site Layout</strong> option is set to <strong>Stretched</strong> in 'Setup &amp; Layout > Site Setup' panel.", 'metrolo' ),
			'section'     => $section,
			'type'        => 'radioimage',
			'choices'     => array(
				'boxed'   => $imagepath . 'slider-width-boxed.png',
				'stretch' => $imagepath . 'slider-width-stretch.png',
			),
			'default'     => 'stretch',
		);

		for ( $slide = 1; $slide <= 4; $slide++ ) {

			$settings["wt_html_slide_{$slide}"] = array(
				'label'       => sprintf( __( 'Slide %s Content', 'metrolo' ), $slide),
				'section'     => $section,
				'type'        => 'group',
				'priority'    => 705, // Non static options must have a priority
				'button'      => sprintf( __( 'Edit Slide %s', 'metrolo' ), $slide),
				'options'     => array(
					'description' => array(
						'label'       => '',
						'type'        => 'content',
						'content'     => '<span class="hoot-module-bg-title">' . sprintf( __( 'Slide %s Content', 'metrolo' ), $slide) . '</span>',
					),
					'image' => array(
						'label'       => __( 'Slide Image', 'metrolo' ),
						'type'        => 'content',
						'description' => __( "The page must have a 'Featured Image' for the slide to display.", 'metrolo' ),
					),
					'content' => array(
						'label'       => __( 'Content (HTML)', 'metrolo' ),
						'type'        => 'select',
						'choices'     => array( __( 'Select Page', 'metrolo' ) ) + HybridExtend_Options_Helper::pages(),
					),
					'content_bg' => array(
						'label'   => __( 'Content Styling', 'metrolo' ),
						'type'    => 'select',
						'default' => 'dark-on-light',
						'choices' => array(
							'dark-on-light' => __('Dark Font / Light Background', 'metrolo'),
							'light-on-dark' => __('Light Font / Dark Background', 'metrolo'),
						),
					),
					'button' => array(
						'label'       => __( 'Link Text', 'metrolo' ),
						'type'        => 'text',
					),
					'url' => array(
						'label'       => __( 'Link URL', 'metrolo' ),
						'type'        => 'url',
						'description' => __( 'Leave empty if you do not want to show the link.', 'metrolo' ),
						'input_attrs' => array(
							'placeholder' => 'http://',
						),
					),
					'background' => array(
						'label'       => __( 'Slide Background', 'metrolo' ),
						'type'        => 'color',
						'description' => __("This can be useful if you are using transparent images", 'metrolo'),
						'default'     => $wt_html_slide_background,
					),
				),
			);

		} // end for

		$section = 'slider_img';

		$sections[ $section ] = array(
			'title'       => __( 'Widgetized Template - Image Slider', 'metrolo' ),
			'panel'       => $panel,
		);

		$settings['wt_img_slider_width'] = array(
			'label'       => __( 'Slider Width', 'metrolo' ),
			'sublabel'    => __("Note: This option is useful only if the <strong>Site Layout</strong> option is set to <strong>Stretched</strong> in 'Setup &amp; Layout > Site Setup' panel.", 'metrolo'),
			'section'     => $section,
			'type'        => 'radioimage',
			'choices'     => array(
				'boxed'   => $imagepath . 'slider-width-boxed.png',
				'stretch' => $imagepath . 'slider-width-stretch.png',
			),
			'default'     => 'boxed',
		);

		for ( $slide = 1; $slide <= 4; $slide++ ) { 

			$settings["wt_img_slide_{$slide}"] = array(
				'label'       => '',//sprintf( __( 'Slide %s Content', 'metrolo' ), $slide),
				'section'     => $section,
				'type'        => 'group',
				'priority'    => 715, // Non static options must have a priority
				'button'      => sprintf( __( 'Edit Slide %s', 'metrolo' ), $slide),
				'options'     => array(
					'description' => array(
						'label'       => '',
						'type'        => 'content',
						'content'     => '<span class="hoot-module-bg-title">' . sprintf( __( 'Slide %s Content', 'metrolo' ), $slide) . '</span>',
					),
					'image' => array(
						'label'       => __( 'Slide Image', 'metrolo' ),
						'type'        => 'image',
						'description' => __( 'The main showcase image.', 'metrolo' ),
					),
					'caption' => array(
						'label'       => __( 'Slide Caption (optional)', 'metrolo' ),
						'type'        => 'text',
					),
					'caption_bg' => array(
						'label'   => __( 'Caption Styling', 'metrolo' ),
						'type'    => 'select',
						'default' => 'accent',
						'choices' => array(
							'accent'        => __('Accent Color Background', 'metrolo'),
							'invert-accent' => __('Accent Color Font', 'metrolo'),
							'dark-on-light' => __('Dark Font / Light Background', 'metrolo'),
							'light-on-dark' => __('Light Font / Dark Background', 'metrolo'),
						),
					),
					'url' => array(
						'label'       => __( 'Slide Link', 'metrolo' ),
						'type'        => 'url',
						'description' => __( 'Leave empty if you do not want to link the slide.', 'metrolo' ),
						'input_attrs' => array(
							'placeholder' => 'http://',
						),
					),
					'button' => array(
						'label'       => __( 'Button Text (Optional)', 'metrolo' ),
						'type'        => 'text',
						'description' => __( 'Leave empty if you do not want to show the button and instead link the slide image (if you have a url set in the above field)', 'metrolo' ),
					),
				),
			);

		} // end for

	endif;


	/*** Return Options Array ***/
	return apply_filters( 'hoot_theme_customizer_options', array(
		'settings' => $settings,
		'sections' => $sections,
		'panels'   => $panels,
	) );

}
endif;

/**
 * Add Options (settings, sections and panels) to HybridExtend_Customize class options object
 *
 * @since 1.0
 * @access public
 * @return void
 */
if ( !function_exists( 'hoot_theme_add_customizer_options' ) ) :
function hoot_theme_add_customizer_options() {

	$hybridextend_customize = HybridExtend_Customize::get_instance();

	// Add Options
	$options = hoot_theme_customizer_options();
	$hybridextend_customize->add_options( array(
		'settings' => $options['settings'],
		'sections' => $options['sections'],
		'panels' => $options['panels'],
		) );

}
endif;
add_action( 'init', 'hoot_theme_add_customizer_options', 0 ); // cannot hook into 'after_setup_theme' as this hook is already being executed (this file is loaded at after_setup_theme @priority 10) (hooking into same hook from within while hook is being executed leads to undesirable effects as $GLOBALS[$wp_filter]['after_setup_theme'] has already been ksorted)
// Hence, we hook into 'init' @priority 0, so that settings array gets populated before 'widgets_init' action ( which itself is hooked to 'init' at priority 1 ) for creating widget areas ( settings array is needed for creating defaults when user value has not been stored )

/**
 * Enqueue custom scripts to customizer screen
 *
 * @since 1.0
 * @return void
 */
function hoot_theme_customizer_enqueue_scripts() {
	// Enqueue Styles
	wp_enqueue_style( 'hoot-theme-customize-styles', HYBRIDEXTEND_INCURI . 'admin/css/customize.css', array(),  HYBRIDEXTEND_VERSION );
	// Enqueue Scripts
	wp_enqueue_script( 'hoot-theme-customize-script', HYBRIDEXTEND_INCURI . 'admin/js/customize.js', array( 'jquery', 'wp-color-picker', 'customize-controls', 'hybridextend-customize-script' ), HYBRIDEXTEND_VERSION, true );
}
// Load scripts at priority 11 so that Hoot Customizer Custom Controls have loaded their scripts
add_action( 'customize_controls_enqueue_scripts', 'hoot_theme_customizer_enqueue_scripts', 12 );

/**
 * Modify default WordPress Settings Sections and Panels
 *
 * @since 1.0
 * @param object $wp_customize
 * @return void
 */
function hoot_customizer_modify_default_options( $wp_customize ) {

	if ( function_exists( 'the_custom_logo' ) ) {
		$wp_customize->get_control( 'custom_logo' )->section = 'logo';
		$wp_customize->get_control( 'custom_logo' )->priority = 55; // Replaces theme's logo_image // Update in premium if needed
		$wp_customize->get_control( 'custom_logo' )->width = 250;
		$wp_customize->get_control( 'custom_logo' )->height = 90;
		// $wp_customize->get_control( 'custom_logo' )->type = 'image'; // Stored value becomes url instead of image ID (fns like the_custom_logo() dont work)
		// Defaults: [type] => cropped_image, [width] => 150, [height] => 150, [flex_width] => 1, [flex_height] => 1, [button_labels] => array(...), [label] => Logo
		$wp_customize->get_control( 'custom_logo' )->active_callback = 'hoot_callback_logo_image';
	}

	$wp_customize->get_section( 'title_tagline' )->panel = 'general';
	$wp_customize->get_section( 'title_tagline' )->priority = 1;

	$wp_customize->get_section( 'static_front_page' )->panel = 'content';
	$wp_customize->get_section( 'static_front_page' )->priority = 1;

	$wp_customize->get_section( 'colors' )->panel = 'styling';
	$wp_customize->get_section( 'background_image' )->panel = 'styling';

	// global $wp_version;
	// if ( version_compare( $wp_version, '4.3', '>=' ) ) // 'Creating Default Object from Empty Value' error before 4.3 since 'nav_menus' panel did not exist ( we did have 'nav' section till 4.1.9 i.e. before 4.2 )
	// 	$wp_customize->get_panel( 'nav_menus' )->priority = 999;
	// This will set the priority, however will give a 'Creating Default Object from Empty Value' error first.
	// $wp_customize->get_panel( 'widgets' )->priority = 999;

}
add_action( 'customize_register', 'hoot_customizer_modify_default_options', 100 );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @since 1.0
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 * @return void
 */
function hoot_customizer_customize_register( $wp_customize ) {
	// $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
}
add_action( 'customize_register', 'hoot_customizer_customize_register' );

/**
 * Callback Functions for customizer settings
 */

function hoot_callback_logo_size( $control ) {
	$selector = $control->manager->get_setting('logo')->value();
	return ( $selector == 'text' || $selector == 'mixed' ) ? true : false;
}
function hoot_callback_site_title_icon( $control ) {
	$selector = $control->manager->get_setting('logo')->value();
	return ( $selector == 'text' || $selector == 'custom' ) ? true : false;
}
function hoot_callback_logo_image( $control ) {
	$selector = $control->manager->get_setting('logo')->value();
	return ( $selector == 'image' || $selector == 'mixed' || $selector == 'mixedcustom' ) ? true : false;
}
function hoot_callback_logo_image_width( $control ) {
	$selector = $control->manager->get_setting('logo')->value();
	return ( $selector == 'mixed' || $selector == 'mixedcustom' ) ? true : false;
}
function hoot_callback_logo_custom( $control ) {
	$selector = $control->manager->get_setting('logo')->value();
	return ( $selector == 'custom' || $selector == 'mixedcustom' ) ? true : false;
}
function hoot_callback_show_tagline( $control ) {
	$selector = $control->manager->get_setting('logo')->value();
	return ( $selector == 'text' || $selector == 'custom' || $selector == 'mixed' || $selector == 'mixedcustom' ) ? true : false;
}
function hoot_callback_show_primary_menuarea_custom( $control ) {
	$selector = $control->manager->get_setting('primary_menuarea')->value();
	return ( $selector == 'custom' ) ? true : false;
}

function hoot_callback_box_background_color( $control ) {
	$selector = $control->manager->get_setting('site_layout')->value();
	return ( $selector == 'boxed' ) ? true : false;
}

/**
 * Specific Sanitization Functions for customizer settings
 * This is disabled by default. Users need to add filter to enable this.
 * See specific settings above for more details.
 */
function hoot_custom_sanitize_textarea_allowscript( $value ) {
	global $allowedposttags;
	// Allow javascript to let users ad code for ads etc.
	$allow = array_merge( $allowedposttags, array(
		'script' => array( 'type' => true, ),
	) );
	return wp_kses( $value , $allow );
}

/**
 * Helper function to return the theme mod value.
 * If no value has been saved, it returns $default provided by the theme.
 * If no $default provided, it checks the default value specified in the customizer settings..
 * 
 * @since 2.0.0
 * @access public
 * @param string $name
 * @param mixed $default
 * @return mixed
 */
function hoot_get_mod( $name, $default = NULL ) {

	if ( is_customize_preview() ) {

		// We cannot use "if ( !empty( $mod ) )" as this will become false for empty values, and hence fallback to default. isset() is not an option either as $mod is always set. Hence we calculate the default here, and supply it as second argument to get_theme_mod()
		$default = ( $default !== NULL ) ? $default : hybridextend_customize_get_default( $name );
		$mod = get_theme_mod( $name, $default );

		return apply_filters( 'hoot_get_mod_customize', $mod, $name, $default );

	} else {

		/*** Return value if set ***/

		// Cache
		static $mods = NULL;

		// Get the values from database
		if ( !$mods ) {
			$mods = get_theme_mods();
			$mods = apply_filters( 'hoot_get_mod', $mods );
		}

		if ( isset( $mods[$name] ) ) {
			// Filter applied as in get_theme_mod() core function
			$mods[$name] = apply_filters( "theme_mod_{$name}", $mods[$name] );
			// Add exceptions: If a value has been set but is empty, this gives the option to return default values in such cases. Simply return $override as (bool)true.
			$override = apply_filters( 'hoot_get_mod_override_empty_values', false, $name, $mods[$name] );
			if ( $override !== true )
				return apply_filters( 'hoot_sanitize_get_mod', $mods[$name], $name );
		}

		/*** Return default if provided ***/
		if ( $default !== NULL )
			return apply_filters( "theme_mod_{$name}", $default );

		/*** Return default theme option value specified in customizer settings ***/
		$default = hybridextend_customize_get_default( $name );
		if ( !empty( $default ) )
			return apply_filters( "theme_mod_{$name}", $default );

	}

	/*** We dont have anything! ***/
	return false;
}

/**
 * Sanitization function for return value of theme mod
 * 
 * @since 1.0
 * @access public
 * @param mixed $value
 * @param string $name
 * @return mixed
 */
function hoot_sanitize_get_mod( $value, $name ) {

	/** Get Setting array from the Customizer Class **/
	$hybridextend_customize = HybridExtend_Customize::get_instance();
	$settings = $hybridextend_customize->get_options('settings');

	if ( isset( $settings[ $name ] ) ) {

		/** Load Sanitization functions if not loaded already (for frontend) **/
		if ( !function_exists( 'hybridextend_sanitize_enum' ) )
			require_once( HYBRIDEXTEND_DIR . 'includes/sanitization.php' );

		/** Sanitize values **/
		if ( isset( $settings[ $name ]['type'] ) ) {
			switch ( $settings[ $name ]['type'] ) {

				// Text Field
				case 'text':
					$value = sanitize_text_field( $value ); // Alternately, can also use "hybridextend_customize_sanitize_text" to use wp_kses() instead
					break;

				// Textarea Field
				case 'textarea':
					$value = hybridextend_sanitize_textarea( $value );
					break;

				// Select, Radio, Image Radio
				case 'select':
				case 'radio':
				case 'radioimage':
					$value = hybridextend_sanitize_enum( $value, $settings[ $name ]['choices'] );
					break;

				// Image / Upload Field
				case 'image':
				case 'upload':
					$value = esc_url( $value );
					break;

				// URL Field
				case 'url':
					$value = esc_url( $value );
					break;

				// Range Field
				case 'range':
					$value = hybridextend_customize_sanitize_range( $value );
					break;

				// Dropdown Pages Field
				case 'dropdown-pages':
					$value = absint( $value );
					break;

				// Color Field
				case 'color':
					$value = sanitize_hex_color( $value );
					break;

				// Checkbox Field
				case 'checkbox':
					$value = hybridextend_sanitize_checkbox( $value );
					break;

				// MultiCheckbox Field
				case 'bettercheckbox':
					if ( !empty( $settings[ $name ]['choices'] ) && is_array( $settings[ $name ]['choices'] ) )
						$value = hybridextend_customize_sanitize_multicheckbox( $value, $name );
					else
						$value = hybridextend_sanitize_checkbox( $value );
					break;

				// Icon Field
				case 'icon':
					$value = hybridextend_sanitize_icon( $value, $name );
					break;

				// Sortlist Field
				case 'sortlist':
					$value = hybridextend_customize_sanitize_sortlist( $value, $name );
					break;

			} // endswitch
		} // endif

	} // endif

	return $value;
}